
CREATE SCHEMA api;


--ALTER SCHEMA api OWNER TO postgres;

--
-- Name: SCHEMA api; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA api IS 'Схема для UserProfileService API на PostgREST';


--
-- Name: logs; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA logs;


--ALTER SCHEMA logs OWNER TO postgres;

--
-- Name: profile; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA profile;


--ALTER SCHEMA profile OWNER TO postgres;



--
-- Name: webhook; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA webhook;


--ALTER SCHEMA webhook OWNER TO postgres;

--
-- Name: SCHEMA webhook; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA webhook IS 'Схема для Webhook API';


--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


--
-- Name: uuid-ossp; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS "uuid-ossp" WITH SCHEMA public;


SET search_path = profile, pg_catalog;

CREATE SEQUENCE r_address_type_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.r_address_type_id_seq OWNER TO postgres;

--
-- Name: r_address_type; Type: TABLE; Schema: profile; Owner: postgres
--


CREATE TABLE r_address_type (
    id smallint DEFAULT nextval('r_address_type_id_seq'::regclass) NOT NULL,
    code text NOT NULL,
    name text NOT NULL
);


--ALTER TABLE profile.r_address_type OWNER TO postgres;

--
-- Name: TABLE r_address_type; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_address_type IS 'Тип адреса. Пользователь: рабочий, домашний. Организация: юридический, фактический.';



--
-- Name: address_type; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE address_type AS (
	postcode character varying(6),
	regioncode character varying(2),
	regionname character varying(255),
	autocode character varying(1),
	autoname character varying(255),
	areacode character varying(3),
	areaname character varying(255),
	citycode character varying(3),
	cityname character varying(255),
	streetcode character varying(4),
	streetname character varying(255),
	housenum character varying(20),
	buildnum character varying(10),
	apartment character varying(6)
);


--ALTER TYPE profile.address_type OWNER TO postgres;

--
-- Name: crtd_at_ts; Type: DOMAIN; Schema: profile; Owner: postgres
--

CREATE DOMAIN crtd_at_ts AS bigint NOT NULL DEFAULT ((date_part('epoch'::text, (now())::timestamp without time zone) * (1000)::double precision))::bigint;


--ALTER DOMAIN profile.crtd_at_ts OWNER TO postgres;

--
-- Name: enum_contact_attribute_type; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE enum_contact_attribute_type AS ENUM (
    'main_email',
    'email',
    'phone',
    'org_phone',
    'firebase_id'
);


--ALTER TYPE profile.enum_contact_attribute_type OWNER TO postgres;

--
-- Name: TYPE enum_contact_attribute_type; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TYPE enum_contact_attribute_type IS 'Типы контактов. Подробное описание во view profile.enum_contact_attribute_type_view';


--
-- Name: enum_delivery_status; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE enum_delivery_status AS ENUM (
    'D',
    'ND'
);


--ALTER TYPE profile.enum_delivery_status OWNER TO postgres;

--
-- Name: TYPE enum_delivery_status; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TYPE enum_delivery_status IS 'D - доставлено
ND - не доставлено';


--
-- Name: enum_gender; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE enum_gender AS ENUM (
    'M',
    'F'
);


--ALTER TYPE profile.enum_gender OWNER TO postgres;

--
-- Name: TYPE enum_gender; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TYPE enum_gender IS 'M - Male
F - Female';


--
-- Name: enum_legal_status; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE enum_legal_status AS ENUM (
    'AGENCY',
    'LEGAL',
    'INDIVIDUAL'
);


--ALTER TYPE profile.enum_legal_status OWNER TO postgres;

--
-- Name: TYPE enum_legal_status; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TYPE enum_legal_status IS 'Правовой статус:
AGENCY - гос. организация
LEGAL - юридическое лицо
INDIVIDUAL - индивидуальный предприниматель (ИП)';


--
-- Name: enum_profile_type; Type: TYPE; Schema: profile; Owner: postgres
--

CREATE TYPE enum_profile_type AS ENUM (
    'user',
    'org'
);


--ALTER TYPE profile.enum_profile_type OWNER TO postgres;

--
-- Name: TYPE enum_profile_type; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TYPE enum_profile_type IS 'Тип профиля:
user - пользователь
org - организация';


CREATE TABLE address (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    address_type smallint,
    profile_id uuid,
    account_no text,
    address address_type,
    fias_id uuid,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.address OWNER TO postgres;


CREATE TABLE organization_profile (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    short_name text NOT NULL,
    full_name text NOT NULL,
    legal_status enum_legal_status NOT NULL,
    corporate_form_id integer,
    registration_date date NOT NULL,
    inn character varying(12) NOT NULL,
    kpp character varying(9) NOT NULL,
    ogrn character varying(15) NOT NULL,
    head_person text,
    representative_person text,
    main_okved jsonb,
    additional_okved jsonb,
    created_at crtd_at_ts NOT NULL,
    website text,
    verified boolean DEFAULT false NOT NULL,
    logo text,
    description text
);


--ALTER TABLE profile.organization_profile OWNER TO postgres;

--
-- Name: TABLE organization_profile; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE organization_profile IS 'Сведения об организации';


--
-- Name: COLUMN organization_profile.short_name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.short_name IS 'Краткое наименование';


--
-- Name: COLUMN organization_profile.full_name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.full_name IS 'Полное наименование организации';


--
-- Name: COLUMN organization_profile.legal_status; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.legal_status IS 'Правовой статус: юридическое лицо, индивидуальный предприниматель';


--
-- Name: COLUMN organization_profile.corporate_form_id; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.corporate_form_id IS 'Организационно-правовая форма организации';


--
-- Name: COLUMN organization_profile.inn; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.inn IS 'ИНН (длина 12 - ИП, длина 10 - ЮЛ)';


--
-- Name: COLUMN organization_profile.ogrn; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.ogrn IS 'ЮЛ - ОГРН (13 символов)
ИП - ОГРНИП (15 символов)';


--
-- Name: COLUMN organization_profile.head_person; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.head_person IS 'ФИО руководителя организации';


--
-- Name: COLUMN organization_profile.representative_person; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.representative_person IS 'ФИО контактного лица';


--
-- Name: COLUMN organization_profile.main_okved; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.main_okved IS 'Основной вид деятельности (ОКВЭД).
01 - Растениеводство и животноводство, охота и предоставление соответствующих услуг в этих областях
02 - Лесоводство и лесозаготовки
и т. д.

Структура содержимого: {code:<code>, title:<title>}';


--
-- Name: COLUMN organization_profile.additional_okved; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.additional_okved IS 'Дополнительные виды деятельности (ОКВЭД).
Структура содержимого: [{code:<code>, title:<title>}]';


--
-- Name: COLUMN organization_profile.verified; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.verified IS 'Подтверждённая/не подтверждённая';


--
-- Name: COLUMN organization_profile.logo; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.logo IS 'Cсылка на логотип';


--
-- Name: COLUMN organization_profile.description; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN organization_profile.description IS 'Описание организации';




SET search_path = logs, pg_catalog;

--
-- Name: create_log_tables(oid); Type: FUNCTION; Schema: logs; Owner: postgres
--

CREATE FUNCTION create_log_tables(table_oid oid) RETURNS integer
    LANGUAGE plpgsql SECURITY DEFINER COST 1
    AS $$
declare
	log_namespace oid=(SELECT oid from pg_namespace WHERE nspname='logs');
	p_relname text;
	new_tbl_name text;
	safe_table_name text;
BEGIN
	SELECT relname FROM pg_class WHERE oid=table_oid INTO p_relname;
	SELECT quote_ident(nspname||'.'||relname) FROM pg_class cl inner join pg_namespace nsp ON (cl.relnamespace=nsp.oid) where cl.oid=table_oid INTO safe_table_name;
	/*Генерация нового имени для таблицы*/
	SELECT replace(safe_table_name,'"','')||'_'||(now()::date)::text||'('||i||')' FROM generate_series(1,10) a(i)
	WHERE replace(safe_table_name,'"','')||'_'||(now()::date)::text||'('||i||')' not in(select relname from pg_class where relnamespace=log_namespace and relpersistence='p')
	ORDER BY i LIMIT 1 INTO new_tbl_name;
	/*Переименовываем старую таблицу с логами*/
	EXECUTE 'ALTER TABLE IF EXISTS logs.'||safe_table_name|| ' RENAME TO '||quote_ident(new_tbl_name)||';';
	/*Создаем таблицу с такой же структурой, как логгируемая, плюс служебные поля*/
	EXECUTE 'create table logs.'||safe_table_name||' (like '||table_oid::regclass||');';
	EXECUTE 'ALTER TABLE logs.'||safe_table_name||' ADD COLUMN "'||p_relname||'_timestamp" timestamp with time zone;';
	EXECUTE 'ALTER TABLE logs.'||safe_table_name||' ADD COLUMN "'||p_relname||'_operation" char;';
	EXECUTE 'ALTER TABLE logs.'||safe_table_name||' ADD COLUMN "'||p_relname||'_user" text;';
	/*Подключаем триггер*/
	EXECUTE 'DROP TRIGGER IF exists tr_log_table ON '||table_oid::regclass::text||';
	CREATE TRIGGER tr_log_table
	BEFORE UPDATE OR DELETE OR INSERT
	ON '||table_oid::regclass::text||'
	FOR EACH ROW
	EXECUTE PROCEDURE logs.tf_log_table();';
	RETURN 0;
end;
$$;


--ALTER FUNCTION logs.create_log_tables(table_oid oid) OWNER TO postgres;

--
-- Name: tf_log_table(); Type: FUNCTION; Schema: logs; Owner: postgres
--

CREATE FUNCTION tf_log_table() RETURNS trigger
    LANGUAGE plpgsql SECURITY DEFINER COST 1
    AS $_$
DECLARE
    query text;
    safe_table_name text;
BEGIN
    SELECT quote_ident(nspname||'.'||relname)
    FROM pg_class cl INNER JOIN pg_namespace nsp ON (cl.relnamespace=nsp.oid)
    WHERE cl.oid=TG_RELID INTO safe_table_name;
    
    query='INSERT INTO logs.'||safe_table_name||' SELECT ($1).*, now(),$2,session_user;';
    
    IF (TG_OP = 'DELETE')
    THEN
    	EXECUTE query using OLD,'D';
    	RETURN OLD;
    ELSIF (TG_OP = 'UPDATE') THEN
    	EXECUTE query using OLD,'U';
    	RETURN NEW;
    ELSIF (TG_OP = 'INSERT') THEN
    	EXECUTE query using NEW,'I';
    	RETURN NEW;
    END IF;
    
    /*Если таблица для логов не создана или ее структура отличается от текущей, то пересоздаем ее, и снова пытаемся записать туда данные*/
    EXCEPTION
    WHEN SQLSTATE '42P01' OR SQLSTATE '42801' OR SQLSTATE '42804' THEN
    	PERFORM logs.create_log_tables(TG_RELID::regclass);
    	IF (TG_OP = 'DELETE') THEN
    	EXECUTE query using OLD,'D';
    	RETURN OLD;
    	ELSIF (TG_OP = 'UPDATE') THEN
    	EXECUTE query using OLD,'U';
    	RETURN NEW;
    	ELSIF (TG_OP = 'INSERT') THEN
    	EXECUTE query using NEW,'I';
    	RETURN NEW;
    	END IF;
    /* Если что-то другое, игнорируем ошибку и возвращаем стандартный ответ*/
    WHEN OTHERS then
        IF (TG_OP = 'DELETE') THEN
            RETURN OLD;
        ELSE
            RETURN NEW;
        END IF;
END;
$_$;


--ALTER FUNCTION logs.tf_log_table() OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: crtd_totimestamp(bigint); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION crtd_totimestamp(bigint) RETURNS timestamp without time zone
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$SELECT to_timestamp($1 / 1000.0)::timestamp;$_$;


--ALTER FUNCTION profile.crtd_totimestamp(bigint) OWNER TO postgres;

--
-- Name: fn_fill_data(); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION fn_fill_data() RETURNS void
    LANGUAGE plpgsql COST 1
    AS $$
DECLARE profile_id1 uuid = uuid_generate_v4();
	DECLARE profile_id2 uuid = uuid_generate_v4();
	DECLARE address_id1 uuid = uuid_generate_v4();
	DECLARE address_id2 uuid = uuid_generate_v4();
	DECLARE address_id3 uuid = uuid_generate_v4();
	DECLARE address_id4 uuid = uuid_generate_v4();
	DECLARE address_id5 uuid = uuid_generate_v4();
	DECLARE org_id1 uuid = uuid_generate_v4();
	DECLARE org_id2 uuid = uuid_generate_v4();
	DECLARE org_id3 uuid = uuid_generate_v4();
	DECLARE contact_attribute1 uuid = uuid_generate_v4();
	DECLARE contact_attribute2 uuid = uuid_generate_v4();
	DECLARE contact_attribute3 uuid = uuid_generate_v4();
	DECLARE contact_attribute4 uuid = uuid_generate_v4();
	DECLARE contact_attribute5 uuid = uuid_generate_v4();
	DECLARE contact_attribute6 uuid = uuid_generate_v4();
	begin
		INSERT INTO profile.profile (id, email, profile_type)
		VALUES(profile_id1, 'fghj@yandex.ru', 'user'), (profile_id2, 'gram@google.com', 'user'), (org_id1, 'gram@google.com', 'org'), (org_id2, 'gram@google.com', 'org'), (org_id3, 'gram@google.com', 'org');
		INSERT INTO profile.user_profile (id, user_id, first_name, middle_name, last_name, gender, birth_date) VALUES(profile_id1, '291d58f5-5eff-4e39-9fef-a30010002c66', 'Пётр', 'Сергеевич', 'Иванов', 'M', '1987-03-01'), (profile_id2, '50db7fb0-fd09-405e-ab9a-27e58bac80e5', 'Марфа', 'Николаевна', 'Каримова', 'F', '1952-06-24');	
		
		INSERT INTO profile.contact_attribute (id, address, "type", confirmed, profile_id)
		VALUES(contact_attribute1, 'vadfa@yandex.ru', 'email', false, profile_id1), (contact_attribute2, 'vadfa@google.ru', 'email', true, profile_id1), (contact_attribute3, '+79057896412', 'phone', true, profile_id1),(contact_attribute4, 'vad@ya.ru', 'main_email', false, '3d8566f1-3d27-43ed-a8e6-f9d9f82aa72b'), (contact_attribute5, 'dfa@gle.ru', 'email', true, '3d8566f1-3d27-43ed-a8e6-f9d9f82aa72b'), (contact_attribute6, '+79357894000', 'phone', true, '3d8566f1-3d27-43ed-a8e6-f9d9f82aa72b');
	
		INSERT INTO profile.mtm_contact_delivery_channel(contact_id, delivery_channel_id)
		VALUES(contact_attribute1, 1), (contact_attribute1, 2), (contact_attribute1, 3), (contact_attribute1, 4), (contact_attribute1, 6);
		INSERT INTO profile.organization_profile(id, short_name, full_name, legal_status, corporate_form_id, registration_date, main_okved, ogrn, inn, kpp)
		VALUES(org_id1, 'OOO "МСК"', 'ООО "Московская сетевая компания"', 'LEGAL', 2, '2010-08-14', '{"code":"02", "title":"Лесоводство и лесозаготовки"}', '1187746562410', '7730244524', '145861036'),
			  (org_id2, 'ИП Краюшкин В. К.', 'Индивидуальный предприниматель Краюшкин Василий Константинович', 'INDIVIDUAL', null, '2002-04-04', '{"code":"01", "title":"Растениеводство и животноводство, охота и предоставление соответствующих услуг в этих областях"}', '1187116562555', '5230244512', '0'),
			  (org_id3, 'АО "Ц"', 'Акционерное общество "Ц"', 'AGENCY', 3, '2012-12-30', '{"code":"01", "title":"Растениеводство и животноводство, охота и предоставление соответствующих услуг в этих областях"}', '1187116562425', '7730244247', '145861000');
		INSERT INTO profile.address	(id, address_type, profile_id, account_no, address.cityname, fias_id)
		VALUES(address_id1, 1, profile_id1, '34234367', 'Perm', 'a5a10eb1-a43a-4223-b560-ae59cc147685'),
			  (address_id2, 2, profile_id1, '34234367', 'Smolensk', 'a5a10eb1-a43a-4223-b560-ae59cc14df87'),
			  (address_id3, 3, org_id1, null, 'Акапулько', 'a5a10eb1-a43a-4223-b560-ae59cc147685'),
			  (address_id4, 4, org_id2, null, 'Урюпинск', 'a5a10eb1-a43a-4223-b560-ae59cc147685'),
			  (address_id5, 3, org_id3, null, 'Бомбей', 'a5a10eb1-a43a-4223-b560-ae59cc147685');
			 
		INSERT INTO profile.r_organization_role (code, "name")
		VALUES('DIRECTOR', 'Генеральный директор'), ('DEVELOPER', 'Разработчик');
	
		INSERT INTO profile.mtm_organization_emp(organization_id, user_profile_id, role_id)
		VALUES(org_id1, profile_id1, 2), (org_id2, profile_id1, 1), (org_id3, profile_id2, 2);
	
		INSERT INTO profile.r_notification_type(service_id, code, "name", description)
		VALUES(1, 'NEW_VOTING', 'Новое голосование', 'Появление нового голосования на портале Активный горожанин'), (2, 'PERSONAL_PROBLEM', 'Проблема, созданная мной', 'Сообщение о проблеме пользователя портала');
	
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 1, 1), (profile_id1, 1, 2), (profile_id1, 1, 3), (profile_id1, 1, 4), (profile_id1, 2, 6), (profile_id1, 2, 2), (profile_id1, 2, 4);
		/*INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 1, 2);
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 1, 3);
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 1, 4);
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 2, 6);
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 2, 2);
		INSERT INTO profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id)
		VALUES(profile_id1, 2, 4);*/
	end;
$$;


--ALTER FUNCTION profile.fn_fill_data() OWNER TO postgres;

--
-- Name: fn_notify_ddl_postgrest(); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION fn_notify_ddl_postgrest() RETURNS event_trigger
    LANGUAGE plpgsql COST 1
    AS $$
BEGIN
  NOTIFY ddl_command_end;
END;
$$;


--ALTER FUNCTION profile.fn_notify_ddl_postgrest() OWNER TO postgres;

--
-- Name: format_org_addresses(uuid); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION format_org_addresses(p_org_id uuid) RETURNS json
    LANGUAGE sql
    AS $$
select json_agg(f.*) from (
select 
at.code as TYPE,
(a.address).postcode as "zipCode",
case when length((a.address).cityname)=0 then null else 
concat((a.address).postcode,', г. ',
(a.address).cityname,
', ул. ',
(a.address).streetname,
', ', (a.address).housenum
) end as "addressStr",
(a.address).regionname as region,
(a.address).cityname as city,
(a.address).areaname as area,
(a.address).streetname as street,
(a.address).housenum as house,
(a.address).buildnum as building,
null as struct,
(a.address).apartment as flat,
null as fiasCode
from profile.address a
left join profile.r_address_type at on a.address_type=at.id
where a.profile_id=p_org_id
) f
$$;


--ALTER FUNCTION profile.format_org_addresses(p_org_id uuid) OWNER TO postgres;

--
-- Name: format_org_addresses_full(uuid); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION format_org_addresses_full(p_org_id uuid) RETURNS json
    LANGUAGE sql
    AS $$
select json_agg(f.*) from (
select 
case when length((a.address).cityname)=0 then null else 
concat((a.address).postcode,', г. ',
(a.address).cityname,
', ул. ',
(a.address).streetname,
', ', (a.address).housenum
) end as "addressStr",
a.*
from profile.address a
left join profile.r_address_type at on a.address_type=at.id
where a.profile_id=p_org_id
) f
$$;


--ALTER FUNCTION profile.format_org_addresses_full(p_org_id uuid) OWNER TO postgres;

--
-- Name: format_organization_json(uuid); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION format_organization_json(p_org_id uuid) RETURNS json
    LANGUAGE sql
    AS $$
SELECT row_to_json(f.*) from (
select
  id,
  full_name as "fullName",
  short_name as "shortName",
  legal_status as "legalStatus",
  corporate_form_id as "corporateForm",
  registration_date as "registrationDate",
  inn,
  kpp,
  ogrn,
  head_person as "headPerson",
  representative_person as "representativePerson",
  main_okved,
  additional_okved as okved_add,
  to_timestamp(created_at / 1000)::date as "systemRegistrationDate",
  website,
  logo,
  description,
  profile.format_org_addresses(id) as addresses
FROM 
  profile.organization_profile where id=p_org_id) f;
$$;


--ALTER FUNCTION profile.format_organization_json(p_org_id uuid) OWNER TO postgres;

--
-- Name: format_organization_json_full(uuid); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION format_organization_json_full(p_org_id uuid) RETURNS json
    LANGUAGE sql
    AS $$
SELECT row_to_json(f.*) from (
select
  id,
  full_name as "fullName",
  short_name as "shortName",
  legal_status as "legalStatus",
  corporate_form_id as "corporateForm",
  to_char(registration_date, 'DD.MM.YYYY') as "registrationDate",
  inn,
  kpp,
  ogrn,
  head_person as "headPerson",
  representative_person as "representativePerson",
  main_okved,
  additional_okved as okved_add,
  to_char(to_timestamp(created_at / 1000)::date, 'DD.MM.YYYY') as "systemRegistrationDate",
  website,
  logo,
  description,
  profile.format_org_addresses_full(id) as addresses
FROM 
  profile.organization_profile where id=p_org_id) f;
$$;


--ALTER FUNCTION profile.format_organization_json_full(p_org_id uuid) OWNER TO postgres;

--
-- Name: tr_contact_attribute_ai(); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION tr_contact_attribute_ai() RETURNS trigger
    LANGUAGE plpgsql COST 1
    AS $$
declare
	type_email smallint;
	type_push smallint;
begin
	-- получаем id типов EMAIL и PUSH, записываем их в переменные type_email, type_push
	with v as (select array(select id::text from profile.r_delivery_channel where code in ('EMAIL', 'PUSH') order by code) as t) select t[1], t[2] from v into type_email, type_push;

	if new."type"::text = 'main_email' then
		insert into profile.mtm_contact_delivery_channel(contact_id, delivery_channel_id) values(new.id, type_email);
	end if;

	if new."type"::text = 'firebase_id' then
		insert into profile.mtm_contact_delivery_channel(contact_id, delivery_channel_id) values(new.id, type_push);
	end if;

	return NEW;
end;
$$;


--ALTER FUNCTION profile.tr_contact_attribute_ai() OWNER TO postgres;

--
-- Name: tr_contact_attribute_bd(); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION tr_contact_attribute_bd() RETURNS trigger
    LANGUAGE plpgsql COST 1
    AS $$
declare
	type_email smallint;
	type_push smallint;
begin
	-- получаем id типов EMAIL и PUSH, записываем их в переменные type_email, type_push
	with v as (select array(select id from profile.r_delivery_channel where code in ('EMAIL', 'PUSH') order by code) as t) select t[1], t[2] from v into type_email, type_push;

	if old."type"::text in ('main_email', 'email') then
		delete from profile.mtm_contact_delivery_channel where contact_id = old.id and delivery_channel_id = type_email;
	end if;

	if old."type"::text = 'firebase_id' then
		delete from profile.mtm_contact_delivery_channel where contact_id = old.id and delivery_channel_id = type_push;
	end if;
	
	return old;
end;
$$;


--ALTER FUNCTION profile.tr_contact_attribute_bd() OWNER TO postgres;

--
-- Name: tr_profile_ai(); Type: FUNCTION; Schema: profile; Owner: postgres
--

CREATE FUNCTION tr_profile_ai() RETURNS trigger
    LANGUAGE plpgsql COST 1
    AS $$
begin
	if NEW.email is not null then
	  NEW.email_md5_hash := md5(lower(NEW.email));
	end if;
	return NEW;
end
$$;


--ALTER FUNCTION profile.tr_profile_ai() OWNER TO postgres;

SET search_path = public, pg_catalog;

--
-- Name: attribute_value_trg(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION attribute_value_trg() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
--new.value=new.value||TG_OP;
return NEW;
END;
$$;


--ALTER FUNCTION public.attribute_value_trg() OWNER TO postgres;

--
-- Name: tr_mtm_organization_emp2user_att(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tr_mtm_organization_emp2user_att() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
IF (TG_OP='DELETE') THEN
INSERT INTO user_attribute (name, value, user_id, id) 
select name, json_agg(value), user_id, uuid_generate_v4() from (
select 'organizations'::text as name, profile.format_organization_json(emp.organization_id) as value, emp.user_profile_id as user_id
from profile.mtm_organization_emp emp where emp.user_profile_id=OLD.user_profile_id) f group by name, user_id
    ON CONFLICT (name, user_id) DO UPDATE SET value = EXCLUDED.value;
ELSE 
INSERT INTO user_attribute (name, value, user_id, id) 
select name, json_agg(value), user_id, uuid_generate_v4() from (
select 'organizations'::text as name, profile.format_organization_json(emp.organization_id) as value, emp.user_profile_id as user_id
from profile.mtm_organization_emp emp where emp.user_profile_id=NEW.user_profile_id) f group by name, user_id
    ON CONFLICT (name, user_id) DO UPDATE SET value = EXCLUDED.value;
END IF;
return NEW;
END;
$$;


--ALTER FUNCTION public.tr_mtm_organization_emp2user_att() OWNER TO postgres;

--
-- Name: tr_org_profile2user_att(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tr_org_profile2user_att() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
INSERT INTO user_attribute (name, value, user_id, id) 
select name, json_agg(value), user_id, uuid_generate_v4() from (
select 'organizations'::text as name, profile.format_organization_json(emp2.organization_id) as value, emp2.user_profile_id as user_id
from profile.organization_profile op
inner join profile.mtm_organization_emp emp1 on op.id=emp1.organization_id
inner join profile.mtm_organization_emp emp2 on emp2.user_profile_id=emp1.user_profile_id
where op.id=NEW.id) f group by name, user_id
    ON CONFLICT (name, user_id) DO UPDATE SET value = EXCLUDED.value;
return NEW;
END;
$$;


--ALTER FUNCTION public.tr_org_profile2user_att() OWNER TO postgres;

--
-- Name: tr_user_entity_ins(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tr_user_entity_ins() RETURNS trigger
    LANGUAGE plpgsql COST 1
    AS $$
declare
	dlvr_channel_id smallint;
begin
	if new.service_account_client_link is null then
		select id from profile.r_delivery_channel where code = 'EMAIL' into dlvr_channel_id;
	
		insert into profile.profile(id, email, profile_type, created_at)
		values (new.id::uuid, new.email, 'user', new.created_timestamp)
	    on conflict(id) do update
	    set email = new.email;

		insert into profile.user_profile(id, user_id, first_name, last_name, created_at, username)
		values (new.id::uuid, new.id::varchar, new.first_name, new.last_name, new.created_timestamp, new.username)
	    on conflict(id) do update
	    set first_name = new.first_name, last_name = new.last_name, username = new.username;

	   	insert into profile.mtm_subscription(profile_id, notification_type_id, delivery_channel_id, created_at)
		select new.id::uuid, id, dlvr_channel_id, new.created_timestamp from profile.r_notification_type
	    on conflict (profile_id, notification_type_id, delivery_channel_id) do nothing;

	    if (new.email is not null) then
			insert into profile.contact_attribute(address, "type", profile_id, created_at)
			values(new.email, 'main_email', new.id::uuid, new.created_timestamp)
            on conflict(profile_id, type) WHERE type = 'main_email'::profile.enum_contact_attribute_type do update
            set address=new.email;
	    end if;
	end if;

	return new;
end;
$$;


--ALTER FUNCTION public.tr_user_entity_ins() OWNER TO postgres;

--
-- Name: tr_user_profile_sync(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tr_user_profile_sync() RETURNS trigger
    LANGUAGE plpgsql COST 1
    AS $$
begin
	update public.user_entity
	set first_name=NEW.first_name, last_name=NEW.last_name, username=NEW.user_name
	where id=NEW.id;
end
$$;


--ALTER FUNCTION public.tr_user_profile_sync() OWNER TO postgres;

SET search_path = pg_catalog;

--
-- Name: CAST (bigint AS timestamp without time zone); Type: CAST; Schema: pg_catalog; Owner: 
--

CREATE CAST (bigint AS timestamp without time zone) WITH FUNCTION profile.crtd_totimestamp(bigint) AS IMPLICIT;


SET search_path = api, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: full-profile; Type: TABLE; Schema: api; Owner: postgres
--

CREATE TABLE "full-profile" (
    profile json,
    address json,
    contacts json,
    organizations json,
    subscriptions json
);

ALTER TABLE ONLY "full-profile" REPLICA IDENTITY NOTHING;


--ALTER TABLE api."full-profile" OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: enum_gender_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enum_gender_view AS
 SELECT e.enumlabel AS gender_code,
        CASE e.enumlabel
            WHEN 'M'::name THEN 'Мужской'::text
            WHEN 'F'::name THEN 'Женский'::text
            ELSE NULL::text
        END AS gender_name
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON (((n.oid = t.typnamespace) AND (n.nspname = 'profile'::name))))
  WHERE (t.typname = 'enum_gender'::name);


--ALTER TABLE profile.enum_gender_view OWNER TO postgres;

--
-- Name: profile; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE profile (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    email text,
    email_md5_hash text,
    profile_type enum_profile_type NOT NULL,
    "default" boolean DEFAULT false NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.profile OWNER TO postgres;

--
-- Name: TABLE profile; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE profile IS 'Базовая сущность, соответствует профилям пользователя и организации';


--
-- Name: COLUMN profile.id; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN profile.id IS 'внутренний ИД';


--
-- Name: COLUMN profile.email_md5_hash; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN profile.email_md5_hash IS 'md5-hash email''а, используется для gravatar.com';


--
-- Name: COLUMN profile."default"; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN profile."default" IS 'Профиль по-умолчанию (пользователь или организация)';


--
-- Name: user_profile; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE user_profile (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    user_id character varying(36) NOT NULL,
    first_name text,
    middle_name text,
    last_name text,
    gender enum_gender,
    birth_date date,
    created_at crtd_at_ts NOT NULL,
    passport_series text,
    passport_no text,
    passport_issue_date date,
    passport_issuer_name text,
    passport_issuer_code text,
    snils text,
    inn text,
    username text,
    avatar text
);


--ALTER TABLE profile.user_profile OWNER TO postgres;

--
-- Name: TABLE user_profile; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE user_profile IS 'Базовая сущность профиля пользователя';


--
-- Name: COLUMN user_profile.passport_series; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.passport_series IS 'Серия паспорта';


--
-- Name: COLUMN user_profile.passport_no; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.passport_no IS 'Номер паспорта';


--
-- Name: COLUMN user_profile.passport_issue_date; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.passport_issue_date IS 'Дата выдачи паспорта';


--
-- Name: COLUMN user_profile.passport_issuer_name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.passport_issuer_name IS 'Кем выдан паспорт';


--
-- Name: COLUMN user_profile.passport_issuer_code; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.passport_issuer_code IS 'Код подразделения, выдавшего паспорт';


--
-- Name: COLUMN user_profile.snils; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.snils IS 'СНИЛС';


--
-- Name: COLUMN user_profile.inn; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.inn IS 'ИНН';


--
-- Name: COLUMN user_profile.username; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN user_profile.username IS 'Имя пользователя, берётся из keycloak''а';

SET search_path = api, pg_catalog;

--
-- Name: profile; Type: VIEW; Schema: api; Owner: postgres
--

CREATE VIEW profile AS
 WITH g AS (
         SELECT enum_gender_view.gender_code AS code,
            jsonb_build_object('code', enum_gender_view.gender_code, 'name', enum_gender_view.gender_name) AS gender
           FROM profile.enum_gender_view
        ), pass AS (
         SELECT up_1.id,
            jsonb_build_object('series', up_1.passport_series, 'no', up_1.passport_no, 'issueDate', up_1.passport_issue_date, 'issuerName', up_1.passport_issuer_name, 'issuerCode', up_1.passport_issuer_code) AS passport
           FROM profile.user_profile up_1
        )
 SELECT up.first_name AS "firstName",
    up.middle_name AS "middleName",
    up.last_name AS "lastName",
    up.birth_date AS "birthDate",
    g.gender,
    p.email AS "mainEmail",
    ue.email_verified AS "emailVerified",
    pass.passport,
    up.snils,
    up.inn,
    ue.enabled
   FROM ((((profile.user_profile up
     JOIN profile.profile p ON ((p.id = up.id)))
     JOIN g ON (((up.gender)::text = (g.code)::text)))
     JOIN pass ON ((pass.id = up.id)))
     JOIN public.user_entity ue ON (((up.user_id)::text = (ue.id)::text)));


--ALTER TABLE api.profile OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: address; Type: TABLE; Schema: profile; Owner: postgres
--
--
-- Name: TABLE address; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE address IS 'Адрес пользователя';


--
-- Name: COLUMN address.account_no; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN address.account_no IS 'Номер лицевого счета (для работы с ЖКХ)';


--
-- Name: COLUMN address.fias_id; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN address.fias_id IS 'UUID адреса в ФИАС';


--
-- Name: r_address_type_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

SET search_path = api, pg_catalog;

--
-- Name: profile-addresses; Type: VIEW; Schema: api; Owner: postgres
--

CREATE VIEW "profile-addresses" AS
 WITH addrt AS (
         SELECT r_address_type.id,
            r_address_type.code,
            r_address_type.name
           FROM profile.r_address_type
        )
 SELECT adr1.profile_id AS "profileId",
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT adr.id,
                    ( SELECT row_to_json(t.*) AS json_agg
                           FROM ( SELECT addrt.code,
                                    addrt.name
                                   FROM addrt
                                  WHERE (addrt.id = adr.address_type)) t) AS type,
                    adr.address,
                    adr.account_no AS "accountNo"
                   FROM profile.address adr
                  WHERE (adr.profile_id = adr1.profile_id)) b) AS address
   FROM profile.address adr1
  GROUP BY adr1.profile_id;


--ALTER TABLE api."profile-addresses" OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: contact_attribute; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE contact_attribute (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    address text NOT NULL,
    type enum_contact_attribute_type NOT NULL,
    confirmed boolean DEFAULT false NOT NULL,
    profile_id uuid NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.contact_attribute OWNER TO postgres;

--
-- Name: TABLE contact_attribute; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE contact_attribute IS 'Контактный атрибут (номер телефона, email, идентификатор в соцсети когда-нибудь)';


--
-- Name: COLUMN contact_attribute.confirmed; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN contact_attribute.confirmed IS 'Подтверждён/не подтверждён';


--
-- Name: enum_contact_attribute_type_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enum_contact_attribute_type_view AS
 SELECT e.enumlabel AS contact_attribute_type_code,
        CASE e.enumlabel
            WHEN 'main_email'::name THEN 'Основной адрес электронной почты'::text
            WHEN 'email'::name THEN 'Дополнительный адрес электронной почты'::text
            WHEN 'phone'::name THEN 'Телефон'::text
            WHEN 'org_phone'::name THEN 'Контактный телефон организации'::text
            ELSE NULL::text
        END AS contact_attribute_type_name
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON (((n.oid = t.typnamespace) AND (n.nspname = 'profile'::name))))
  WHERE (t.typname = 'enum_contact_attribute_type'::name);


--ALTER TABLE profile.enum_contact_attribute_type_view OWNER TO postgres;

SET search_path = api, pg_catalog;

--
-- Name: profile-contacts; Type: VIEW; Schema: api; Owner: postgres
--

CREATE VIEW "profile-contacts" AS
 WITH cat AS (
         SELECT enum_contact_attribute_type_view.contact_attribute_type_code AS code,
            enum_contact_attribute_type_view.contact_attribute_type_name AS name
           FROM profile.enum_contact_attribute_type_view
        )
 SELECT c1.profile_id AS "profileId",
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT row_to_json(cat.*) AS type,
                    c.address,
                    c.confirmed
                   FROM (profile.contact_attribute c
                     JOIN cat ON (((c.type)::text = (cat.code)::text)))
                  WHERE (c.profile_id = c1.profile_id)
                  GROUP BY cat.*, c.address, c.confirmed) b) AS contacts
   FROM profile.contact_attribute c1
  GROUP BY c1.profile_id;


--ALTER TABLE api."profile-contacts" OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: enum_legal_status_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enum_legal_status_view AS
 SELECT e.enumlabel AS legal_status_code,
        CASE e.enumlabel
            WHEN 'AGENCY'::name THEN 'Государственная организация'::text
            WHEN 'LEGAL'::name THEN 'Юридическое лицо'::text
            WHEN 'INDIVIDUAL'::name THEN 'Индивидуальный предприниматель (ИП)'::text
            ELSE NULL::text
        END AS legal_status_name
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON (((n.oid = t.typnamespace) AND (n.nspname = 'profile'::name))))
  WHERE (t.typname = 'enum_legal_status'::name);


--ALTER TABLE profile.enum_legal_status_view OWNER TO postgres;

--
-- Name: mtm_organization_emp; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE mtm_organization_emp (
    organization_id uuid NOT NULL,
    user_profile_id uuid NOT NULL,
    role_id smallint NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.mtm_organization_emp OWNER TO postgres;

--
-- Name: TABLE mtm_organization_emp; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE mtm_organization_emp IS 'Сотрудники организации';


--
-- Name: COLUMN mtm_organization_emp.role_id; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN mtm_organization_emp.role_id IS 'Роль в организации';


--
-- Name: organization_profile; Type: TABLE; Schema: profile; Owner: postgres
--
--
-- Name: r_corporate_form_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE r_corporate_form_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 2147483647
    CACHE 1;


--ALTER TABLE profile.r_corporate_form_id_seq OWNER TO postgres;

--
-- Name: r_corporate_form; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE r_corporate_form (
    id integer DEFAULT nextval('r_corporate_form_id_seq'::regclass) NOT NULL,
    code text,
    short_name text,
    full_name text,
    description text
);


--ALTER TABLE profile.r_corporate_form OWNER TO postgres;

--
-- Name: TABLE r_corporate_form; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_corporate_form IS 'Организационно-правовая форма компании: ООО, ПАО, НАО и т. д.';


--
-- Name: COLUMN r_corporate_form.short_name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_corporate_form.short_name IS 'Сокращённое наименование - ООО, ПАО, НАО и т. д.';


--
-- Name: COLUMN r_corporate_form.full_name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_corporate_form.full_name IS 'Полное наименование - общество с ограниченной ответственностью, публичное акционерное общество, непубличное акционерное общество и т. д.';


--
-- Name: r_organization_role_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE r_organization_role_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.r_organization_role_id_seq OWNER TO postgres;

--
-- Name: r_organization_role; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE r_organization_role (
    id smallint DEFAULT nextval('r_organization_role_id_seq'::regclass) NOT NULL,
    code text NOT NULL,
    name text NOT NULL
);


--ALTER TABLE profile.r_organization_role OWNER TO postgres;

--
-- Name: TABLE r_organization_role; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_organization_role IS 'Роль в организации (enum)';


SET search_path = api, pg_catalog;

--
-- Name: profile-organizations; Type: VIEW; Schema: api; Owner: postgres
--

CREATE VIEW "profile-organizations" AS
 WITH r AS (
         SELECT r_organization_role.id,
            r_organization_role.code,
            r_organization_role.name
           FROM profile.r_organization_role
        ), lsv AS (
         SELECT enum_legal_status_view.legal_status_code AS code,
            enum_legal_status_view.legal_status_name AS name
           FROM profile.enum_legal_status_view
        ), corp_form AS (
         SELECT r_corporate_form.id,
            r_corporate_form.code,
            r_corporate_form.short_name,
            r_corporate_form.full_name
           FROM profile.r_corporate_form
        ), addrt AS (
         SELECT r_address_type.id,
            r_address_type.code,
            r_address_type.name
           FROM profile.r_address_type
        ), cat AS (
         SELECT enum_contact_attribute_type_view.contact_attribute_type_code AS code,
            enum_contact_attribute_type_view.contact_attribute_type_name AS name
           FROM profile.enum_contact_attribute_type_view
        )
 SELECT p.id AS "profileId",
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT org.id,
                    ( SELECT row_to_json(t.*) AS row_to_json
                           FROM ( SELECT r.code,
                                    r.name
                                   FROM r
                                  WHERE (r.id = mtm.role_id)) t) AS role,
                    org.short_name AS "shortName",
                    org.full_name AS "fullName",
                    ( SELECT row_to_json(lsv.*) AS row_to_json
                           FROM lsv
                          WHERE ((lsv.code)::text = (org.legal_status)::text)) AS "legalStatus",
                    ( SELECT row_to_json(t.*) AS row_to_json
                           FROM ( SELECT corp_form.code,
                                    corp_form.short_name AS "shortName",
                                    corp_form.full_name AS "fullName"
                                   FROM corp_form
                                  WHERE (corp_form.id = org.corporate_form_id)) t) AS "corporateForm",
                    org.registration_date AS "registrationDate",
                    date(to_timestamp((((org.created_at)::bigint / 1000))::double precision)) AS "systemRegistrationDate",
                    org.ogrn,
                    org.inn,
                    org.kpp,
                    org.head_person AS "headPerson",
                    org.representative_person AS "representativePerson",
                    org.main_okved AS "mainOkved",
                    org.additional_okved AS "additionalOkved",
                    org.website,
                    org.verified,
                    ( SELECT jsonb_agg(b_1.*) AS jsonb_agg
                           FROM ( SELECT ( SELECT row_to_json(t.*) AS row_to_json
   FROM ( SELECT addrt.code,
      addrt.name
     FROM addrt
    WHERE (addrt.id = a.address_type)) t) AS type,
                                    a.address
                                   FROM profile.address a
                                  WHERE (a.profile_id = org.id)) b_1) AS address,
                    ( SELECT jsonb_agg(b_1.*) AS jsonb_agg
                           FROM ( SELECT ( SELECT row_to_json(t.*) AS row_to_json
   FROM ( SELECT cat.code,
      cat.name
     FROM cat
    WHERE (c.id = c.id)) t) AS type,
                                    c.address,
                                    c.confirmed
                                   FROM profile.contact_attribute c
                                  WHERE (c.profile_id = org.id)) b_1) AS contacts
                   FROM (profile.mtm_organization_emp mtm
                     JOIN profile.organization_profile org ON ((mtm.organization_id = org.id)))
                  WHERE (mtm.user_profile_id = p.id)) b) AS organizations
   FROM profile.user_profile p
  GROUP BY p.id;


--ALTER TABLE api."profile-organizations" OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: mtm_subscription; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE mtm_subscription (
    profile_id uuid NOT NULL,
    notification_type_id integer NOT NULL,
    delivery_channel_id smallint NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.mtm_subscription OWNER TO postgres;

--
-- Name: TABLE mtm_subscription; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE mtm_subscription IS 'Подписка на уведомления или рассылку (email, push, sms и т. д.)';


--
-- Name: r_delivery_channel_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE r_delivery_channel_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.r_delivery_channel_id_seq OWNER TO postgres;

--
-- Name: r_delivery_channel; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE r_delivery_channel (
    id smallint DEFAULT nextval('r_delivery_channel_id_seq'::regclass) NOT NULL,
    code text NOT NULL,
    name text
);


--ALTER TABLE profile.r_delivery_channel OWNER TO postgres;

--
-- Name: TABLE r_delivery_channel; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_delivery_channel IS 'Канал доставки уведомлений и рассылок (email, sms, whatsapp, telegram, viber, push)';


--
-- Name: r_notification_type_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE r_notification_type_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.r_notification_type_id_seq OWNER TO postgres;

--
-- Name: r_notification_type; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE r_notification_type (
    id integer DEFAULT nextval('r_notification_type_id_seq'::regclass) NOT NULL,
    service_id integer NOT NULL,
    code text NOT NULL,
    name text NOT NULL,
    description text,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.r_notification_type OWNER TO postgres;

--
-- Name: TABLE r_notification_type; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_notification_type IS 'Типы уведомлений/рассылок (пример: "уведомления о новых голосованиях в АГ", "уведомления об изменении статуса моих задач"). Слайд 006 https://ninjamock.com/s/DHQ2RFx';


--
-- Name: COLUMN r_notification_type.name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_notification_type.name IS 'Наименование типа рассылки';


--
-- Name: COLUMN r_notification_type.description; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_notification_type.description IS 'Описание рассылки (для подсказки)';


--
-- Name: r_service_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE r_service_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.r_service_id_seq OWNER TO postgres;

--
-- Name: r_service; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE r_service (
    id smallint DEFAULT nextval('r_service_id_seq'::regclass) NOT NULL,
    code text NOT NULL,
    name text NOT NULL,
    description text
);


--ALTER TABLE profile.r_service OWNER TO postgres;

--
-- Name: TABLE r_service; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE r_service IS 'Сервис платформы (АГ, Туризм, Малое предпринимательство)';


--
-- Name: COLUMN r_service.name; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_service.name IS 'Наименование сервиса (Активный горожанин, Туризм т. д.)';


--
-- Name: COLUMN r_service.description; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN r_service.description IS 'Описание (подсказка)';


SET search_path = api, pg_catalog;

--
-- Name: profile-subscriptions; Type: VIEW; Schema: api; Owner: postgres
--

CREATE VIEW "profile-subscriptions" AS
 WITH dct AS (
         SELECT r_delivery_channel.id,
            r_delivery_channel.code,
            r_delivery_channel.name
           FROM profile.r_delivery_channel
        ), serv AS (
         SELECT r_service.id,
            r_service.code,
            r_service.name,
            r_service.description
           FROM profile.r_service
        )
 SELECT p.id AS "profileId",
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT ( SELECT json_agg(t.*) AS json_agg
                           FROM ( SELECT nt.code,
                                    nt.name,
                                    nt.description,
                                    ( SELECT row_to_json(t_1.*) AS row_to_json
   FROM ( SELECT serv.code,
      serv.name,
      serv.description
     FROM serv
    WHERE (serv.id = nt.service_id)) t_1) AS service,
                                    ( SELECT json_agg(( SELECT row_to_json(t_1.*) AS row_to_json
     FROM ( SELECT dct.code,
        dct.name
       FROM dct
      WHERE (dct.id = mtm.delivery_channel_id)) t_1)) AS json_agg) AS "deliveryChannel"
                                   FROM (profile.mtm_subscription mtm
                                     JOIN profile.r_notification_type nt ON ((nt.id = mtm.notification_type_id)))
                                  WHERE (mtm.profile_id = p.id)
                                  GROUP BY nt.code, nt.name, nt.description, nt.service_id) t) AS notification) b) AS subscriptions
   FROM profile.user_profile p
  GROUP BY p.id;


--ALTER TABLE api."profile-subscriptions" OWNER TO postgres;

SET search_path = logs, pg_catalog;

--
-- Name: profile.address; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.address" (
    id uuid NOT NULL,
    address_type smallint,
    profile_id uuid,
    account_no text,
    address profile.address_type,
    fias_id uuid NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    address_timestamp timestamp with time zone,
    address_operation character(1),
    address_user text
);


--ALTER TABLE logs."profile.address" OWNER TO postgres;

--
-- Name: profile.contact_attribute; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.contact_attribute" (
    id uuid NOT NULL,
    address text NOT NULL,
    type profile.enum_contact_attribute_type NOT NULL,
    confirmed boolean NOT NULL,
    profile_id uuid NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    contact_attribute_timestamp timestamp with time zone,
    contact_attribute_operation character(1),
    contact_attribute_user text
);


--ALTER TABLE logs."profile.contact_attribute" OWNER TO postgres;

--
-- Name: profile.mtm_contact_delivery_channel; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.mtm_contact_delivery_channel" (
    contact_id uuid NOT NULL,
    delivery_channel_id smallint NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    mtm_contact_delivery_channel_timestamp timestamp with time zone,
    mtm_contact_delivery_channel_operation character(1),
    mtm_contact_delivery_channel_user text
);


--ALTER TABLE logs."profile.mtm_contact_delivery_channel" OWNER TO postgres;

--
-- Name: profile.mtm_organization_emp; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.mtm_organization_emp" (
    organization_id uuid NOT NULL,
    user_profile_id uuid NOT NULL,
    role_id smallint NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    mtm_organization_emp_timestamp timestamp with time zone,
    mtm_organization_emp_operation character(1),
    mtm_organization_emp_user text
);


--ALTER TABLE logs."profile.mtm_organization_emp" OWNER TO postgres;

--
-- Name: profile.mtm_subscription; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.mtm_subscription" (
    profile_id uuid NOT NULL,
    notification_type_id integer NOT NULL,
    delivery_channel_id smallint NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    mtm_subscription_timestamp timestamp with time zone,
    mtm_subscription_operation character(1),
    mtm_subscription_user text
);


--ALTER TABLE logs."profile.mtm_subscription" OWNER TO postgres;

--
-- Name: profile.notification; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.notification" (
    id uuid NOT NULL,
    sender_id uuid,
    organization_id uuid,
    title text NOT NULL,
    short_content text,
    content text,
    notification_type_id integer NOT NULL,
    created_at profile.crtd_at_ts,
    notification_timestamp timestamp with time zone,
    notification_operation character(1),
    notification_user text
);


--ALTER TABLE logs."profile.notification" OWNER TO postgres;

--
-- Name: profile.organization_profile; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.organization_profile" (
    id uuid NOT NULL,
    short_name text NOT NULL,
    full_name text NOT NULL,
    legal_status profile.enum_legal_status NOT NULL,
    corporate_form_id smallint,
    registration_date date NOT NULL,
    inn character varying(12) NOT NULL,
    kpp character varying(9) NOT NULL,
    ogrn character varying(15) NOT NULL,
    head_person text,
    representative_person text,
    main_okved jsonb,
    additional_okved jsonb,
    created_at profile.crtd_at_ts NOT NULL,
    website text,
    verified boolean NOT NULL,
    organization_profile_timestamp timestamp with time zone,
    organization_profile_operation character(1),
    organization_profile_user text
);


--ALTER TABLE logs."profile.organization_profile" OWNER TO postgres;

--
-- Name: profile.profile; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.profile" (
    id uuid NOT NULL,
    email text,
    email_md5_hash text,
    profile_type profile.enum_profile_type NOT NULL,
    "default" boolean NOT NULL,
    created_at profile.crtd_at_ts NOT NULL,
    profile_timestamp timestamp with time zone,
    profile_operation character(1),
    profile_user text
);


--ALTER TABLE logs."profile.profile" OWNER TO postgres;

--
-- Name: profile.user_profile; Type: TABLE; Schema: logs; Owner: postgres
--

CREATE TABLE "profile.user_profile" (
    id uuid NOT NULL,
    user_id character varying(36) NOT NULL,
    first_name text,
    middle_name text,
    last_name text,
    gender profile.enum_gender,
    birth_date date,
    created_at profile.crtd_at_ts NOT NULL,
    passport_series text,
    passport_no text,
    passport_issue_date date,
    passport_issuer_name text,
    passport_issuer_code text,
    snils text,
    inn text,
    username text,
    user_profile_timestamp timestamp with time zone,
    user_profile_operation character(1),
    user_profile_user text
);


--ALTER TABLE logs."profile.user_profile" OWNER TO postgres;

SET search_path = profile, pg_catalog;

--
-- Name: enum_delivery_status_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enum_delivery_status_view AS
 SELECT e.enumlabel AS delivery_status_code,
        CASE e.enumlabel
            WHEN 'D'::name THEN 'Доставлено'::text
            WHEN 'ND'::name THEN 'Не доставлено'::text
            ELSE NULL::text
        END AS delivery_status_name
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON (((n.oid = t.typnamespace) AND (n.nspname = 'profile'::name))))
  WHERE (t.typname = 'enum_delivery_status'::name);


--ALTER TABLE profile.enum_delivery_status_view OWNER TO postgres;

--
-- Name: enum_profile_type_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enum_profile_type_view AS
 SELECT e.enumlabel AS profile_type_code,
        CASE e.enumlabel
            WHEN 'user'::name THEN 'Пользователь'::text
            WHEN 'org'::name THEN 'Организация'::text
            ELSE NULL::text
        END AS profile_type_name
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON (((n.oid = t.typnamespace) AND (n.nspname = 'profile'::name))))
  WHERE (t.typname = 'enum_profile_type'::name);


--ALTER TABLE profile.enum_profile_type_view OWNER TO postgres;

--
-- Name: enums_view; Type: VIEW; Schema: profile; Owner: postgres
--

CREATE VIEW enums_view AS
 SELECT t.typname AS enum_name,
    string_agg((e.enumlabel)::text, ', '::text) AS enum_value,
    n.nspname AS enum_schema
   FROM ((pg_type t
     JOIN pg_enum e ON ((t.oid = e.enumtypid)))
     JOIN pg_namespace n ON ((n.oid = t.typnamespace)))
  GROUP BY n.nspname, t.typname;


--ALTER TABLE profile.enums_view OWNER TO postgres;

--
-- Name: fact_indicator_actual; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE fact_indicator_actual (
    indicator_category_id integer NOT NULL,
    user_id uuid NOT NULL,
    value double precision,
    comment text,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.fact_indicator_actual OWNER TO postgres;

--
-- Name: TABLE fact_indicator_actual; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE fact_indicator_actual IS 'Значение показателя';


--
-- Name: indicator_category_id_seq; Type: SEQUENCE; Schema: profile; Owner: postgres
--

CREATE SEQUENCE indicator_category_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE profile.indicator_category_id_seq OWNER TO postgres;

--
-- Name: indicator_category; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE indicator_category (
    id integer DEFAULT nextval('indicator_category_id_seq'::regclass) NOT NULL,
    service_id integer,
    code text,
    title text,
    description text,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.indicator_category OWNER TO postgres;

--
-- Name: COLUMN indicator_category.code; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN indicator_category.code IS 'Код категории';


--
-- Name: mtm_contact_delivery_channel; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE mtm_contact_delivery_channel (
    contact_id uuid NOT NULL,
    delivery_channel_id smallint NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.mtm_contact_delivery_channel OWNER TO postgres;

--
-- Name: mtm_notification_delivery_task; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE mtm_notification_delivery_task (
    notification_id uuid NOT NULL,
    profile_id uuid NOT NULL,
    delivery_channel_id smallint NOT NULL,
    status enum_delivery_status DEFAULT 'ND'::enum_delivery_status NOT NULL,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.mtm_notification_delivery_task OWNER TO postgres;

--
-- Name: COLUMN mtm_notification_delivery_task.status; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN mtm_notification_delivery_task.status IS 'Доставлено/не доставлено';


--
-- Name: mtm_notification_profile; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE mtm_notification_profile (
    notification_id uuid NOT NULL,
    profile_id uuid NOT NULL,
    seen boolean DEFAULT false,
    created_at crtd_at_ts NOT NULL
);


--ALTER TABLE profile.mtm_notification_profile OWNER TO postgres;

--
-- Name: TABLE mtm_notification_profile; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE mtm_notification_profile IS 'Связывание экземпляра уведомления (notification) с конкретным пользователем для хранения истории уведомлений по каждому пользователю';


--
-- Name: COLUMN mtm_notification_profile.seen; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN mtm_notification_profile.seen IS 'Прочтено/не прочтено';


--
-- Name: notification; Type: TABLE; Schema: profile; Owner: postgres
--

CREATE TABLE notification (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    sender_id uuid,
    organization_id uuid,
    title text NOT NULL,
    short_content text,
    content text,
    notification_type_id integer NOT NULL,
    created_at crtd_at_ts
);


--ALTER TABLE profile.notification OWNER TO postgres;

--
-- Name: TABLE notification; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON TABLE notification IS 'Экземпляр рассылки или уведомления (письмо, сообщение)';


--
-- Name: COLUMN notification.sender_id; Type: COMMENT; Schema: profile; Owner: postgres
--

COMMENT ON COLUMN notification.sender_id IS 'Пользователь-отправитель (например, комментарии или сообщения в рамках прикладных сервисов)';

SET search_path = webhook, pg_catalog;

--
-- Name: mtm_subscriber; Type: TABLE; Schema: webhook; Owner: postgres
--

CREATE TABLE mtm_subscriber (
    service_id smallint NOT NULL,
    endpoint text NOT NULL,
    observable_entity_id smallint NOT NULL,
    enabled boolean DEFAULT true NOT NULL,
    created_at profile.crtd_at_ts NOT NULL
);


--ALTER TABLE webhook.mtm_subscriber OWNER TO postgres;

--
-- Name: TABLE mtm_subscriber; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON TABLE mtm_subscriber IS 'Подписчики на webhook''и';


--
-- Name: COLUMN mtm_subscriber.service_id; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON COLUMN mtm_subscriber.service_id IS 'Идентификатор внешнего сервиса (АГ, Туризм и т. д.)';


--
-- Name: COLUMN mtm_subscriber.endpoint; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON COLUMN mtm_subscriber.endpoint IS 'REST endpoint внешней системы, который будет вызывать webhook';


--
-- Name: COLUMN mtm_subscriber.observable_entity_id; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON COLUMN mtm_subscriber.observable_entity_id IS 'Сущность, при изменении в которой будет вызван webhook';


--
-- Name: COLUMN mtm_subscriber.enabled; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON COLUMN mtm_subscriber.enabled IS 'Действует/приостановлена подписка на webhook';


--
-- Name: r_observable_entity_id_seq; Type: SEQUENCE; Schema: webhook; Owner: postgres
--

CREATE SEQUENCE r_observable_entity_id_seq
    START WITH 1
    INCREMENT BY 1
    MINVALUE 0
    MAXVALUE 32767
    CACHE 1;


--ALTER TABLE webhook.r_observable_entity_id_seq OWNER TO postgres;

--
-- Name: r_observable_entity; Type: TABLE; Schema: webhook; Owner: postgres
--

CREATE TABLE r_observable_entity (
    id smallint DEFAULT nextval('r_observable_entity_id_seq'::regclass) NOT NULL,
    code text,
    name text,
    "desc" text
);


--ALTER TABLE webhook.r_observable_entity OWNER TO postgres;

--
-- Name: TABLE r_observable_entity; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON TABLE r_observable_entity IS 'Наблюдаемая сущность, при изменении в которой будет вызван webhook';


--
-- Name: COLUMN r_observable_entity."desc"; Type: COMMENT; Schema: webhook; Owner: postgres
--

COMMENT ON COLUMN r_observable_entity."desc" IS 'Описание';


SET search_path = profile, pg_catalog;

--
-- Name: fact_indicator_actual fact_indicator_pk; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY fact_indicator_actual
    ADD CONSTRAINT fact_indicator_pk PRIMARY KEY (indicator_category_id, user_id);


--
-- Name: address pk_address; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY address
    ADD CONSTRAINT pk_address PRIMARY KEY (id);


--
-- Name: r_address_type pk_address_type; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_address_type
    ADD CONSTRAINT pk_address_type PRIMARY KEY (id);


--
-- Name: contact_attribute pk_contact_attribute; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY contact_attribute
    ADD CONSTRAINT pk_contact_attribute PRIMARY KEY (id);


--
-- Name: r_delivery_channel pk_delivery_channel; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_delivery_channel
    ADD CONSTRAINT pk_delivery_channel PRIMARY KEY (id);


--
-- Name: indicator_category pk_indicator_category; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY indicator_category
    ADD CONSTRAINT pk_indicator_category PRIMARY KEY (id);


--
-- Name: mtm_contact_delivery_channel pk_mtm_contact_delivery_channel; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_contact_delivery_channel
    ADD CONSTRAINT pk_mtm_contact_delivery_channel PRIMARY KEY (contact_id, delivery_channel_id);


--
-- Name: mtm_notification_profile pk_mtm_notification_profile; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_profile
    ADD CONSTRAINT pk_mtm_notification_profile PRIMARY KEY (notification_id, profile_id);


--
-- Name: mtm_organization_emp pk_mtm_organization_emp; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_organization_emp
    ADD CONSTRAINT pk_mtm_organization_emp PRIMARY KEY (organization_id, user_profile_id, role_id);


--
-- Name: notification pk_notification; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT pk_notification PRIMARY KEY (id);


--
-- Name: mtm_notification_delivery_task pk_notification_delivery_task; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_delivery_task
    ADD CONSTRAINT pk_notification_delivery_task PRIMARY KEY (notification_id, delivery_channel_id, profile_id);


--
-- Name: r_notification_type pk_notification_type; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_notification_type
    ADD CONSTRAINT pk_notification_type PRIMARY KEY (id);


--
-- Name: organization_profile pk_organization; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY organization_profile
    ADD CONSTRAINT pk_organization PRIMARY KEY (id);


--
-- Name: profile pk_profile; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY profile
    ADD CONSTRAINT pk_profile PRIMARY KEY (id);


--
-- Name: r_corporate_form pk_r_corporate form; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_corporate_form
    ADD CONSTRAINT "pk_r_corporate form" PRIMARY KEY (id);


--
-- Name: r_organization_role pk_r_organization_role; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_organization_role
    ADD CONSTRAINT pk_r_organization_role PRIMARY KEY (id);


--
-- Name: r_service pk_r_service; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_service
    ADD CONSTRAINT pk_r_service PRIMARY KEY (id);


--
-- Name: mtm_subscription pk_subscription; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_subscription
    ADD CONSTRAINT pk_subscription PRIMARY KEY (profile_id, notification_type_id, delivery_channel_id);


--
-- Name: user_profile pk_user_profile; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY user_profile
    ADD CONSTRAINT pk_user_profile PRIMARY KEY (id);


--
-- Name: r_notification_type uq_code_and_service_id; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_notification_type
    ADD CONSTRAINT uq_code_and_service_id UNIQUE (code, service_id);


--
-- Name: user_profile uq_user_profile_tbl_user_id; Type: CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY user_profile
    ADD CONSTRAINT uq_user_profile_tbl_user_id UNIQUE (user_id);

SET search_path = webhook, pg_catalog;

--
-- Name: r_observable_entity observable_entity_pk; Type: CONSTRAINT; Schema: webhook; Owner: postgres
--

ALTER TABLE ONLY r_observable_entity
    ADD CONSTRAINT observable_entity_pk PRIMARY KEY (id);


--
-- Name: mtm_subscriber pk_mtm_subscriber; Type: CONSTRAINT; Schema: webhook; Owner: postgres
--

ALTER TABLE ONLY mtm_subscriber
    ADD CONSTRAINT pk_mtm_subscriber PRIMARY KEY (service_id, endpoint, observable_entity_id);


SET search_path = profile, pg_catalog;

--
-- Name: address_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX address_tbl_profile_id_idx ON profile.address USING btree (profile_id) WITH (fillfactor='90');


--
-- Name: contact_attribute_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX contact_attribute_idx ON profile.contact_attribute USING btree (id) WITH (fillfactor='90');


--
-- Name: contact_attribute_main_email_uq_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE UNIQUE INDEX contact_attribute_main_email_uq_idx ON profile.contact_attribute USING btree (profile_id, type) WHERE (type = 'main_email'::enum_contact_attribute_type);


--
-- Name: contact_attribute_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX contact_attribute_tbl_profile_id_idx ON profile.contact_attribute USING btree (profile_id) WITH (fillfactor='90');


--
-- Name: mtm_contact_delivery_channel_tbl_contact_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_contact_delivery_channel_tbl_contact_id_idx ON profile.mtm_contact_delivery_channel USING btree (contact_id) WITH (fillfactor='90');


--
-- Name: mtm_contact_delivery_channel_tbl_delivery_channel_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_contact_delivery_channel_tbl_delivery_channel_id_idx ON profile.mtm_contact_delivery_channel USING btree (delivery_channel_id) WITH (fillfactor='90');


--
-- Name: mtm_notification_profile_tbl_notification_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_notification_profile_tbl_notification_id_idx ON profile.mtm_notification_profile USING btree (notification_id);


--
-- Name: mtm_notification_profile_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_notification_profile_tbl_profile_id_idx ON profile.mtm_notification_profile USING btree (profile_id);


--
-- Name: mtm_organization_emp_tbl_organization_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_organization_emp_tbl_organization_id_idx ON profile.mtm_organization_emp USING btree (organization_id) WITH (fillfactor='90');


--
-- Name: mtm_organization_emp_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_organization_emp_tbl_profile_id_idx ON profile.mtm_organization_emp USING btree (user_profile_id) WITH (fillfactor='90');


--
-- Name: mtm_subscription_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX mtm_subscription_tbl_profile_id_idx ON profile.mtm_subscription USING btree (profile_id) WITH (fillfactor='90');


--
-- Name: notification_delivery_task_tbl_notification_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX notification_delivery_task_tbl_notification_id_idx ON profile.mtm_notification_delivery_task USING btree (notification_id);


--
-- Name: notification_delivery_task_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX notification_delivery_task_tbl_profile_id_idx ON profile.mtm_notification_delivery_task USING btree (profile_id);


--
-- Name: notification_tbl_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX notification_tbl_id_idx ON profile.notification USING btree (id);


--
-- Name: notification_tbl_organization_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX notification_tbl_organization_id_idx ON profile.notification USING btree (organization_id);


--
-- Name: notification_tbl_sender_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX notification_tbl_sender_id_idx ON profile.notification USING btree (sender_id);


--
-- Name: organization_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX organization_idx ON profile.organization_profile USING btree (id) WITH (fillfactor='90');


--
-- Name: profile_tbl_profile_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX profile_tbl_profile_id_idx ON profile.profile USING btree (id) WITH (fillfactor='90');


--
-- Name: user_profile_tbl_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX user_profile_tbl_id_idx ON profile.user_profile USING btree (id);


--
-- Name: user_profile_tbl_user_id_idx; Type: INDEX; Schema: profile; Owner: postgres
--

CREATE INDEX user_profile_tbl_user_id_idx ON profile.user_profile USING btree (user_id);

SET search_path = api, pg_catalog;

--
-- Name: full-profile _RETURN; Type: RULE; Schema: api; Owner: postgres
--

CREATE RULE "_RETURN" AS
    ON SELECT TO api."full-profile" DO INSTEAD  WITH g AS (
         SELECT enum_gender_view.gender_code AS code,
            jsonb_build_object('code', enum_gender_view.gender_code, 'name', enum_gender_view.gender_name) AS gender
           FROM profile.enum_gender_view
        ), pass AS (
         SELECT up_1.id,
            jsonb_build_object('series', up_1.passport_series, 'no', up_1.passport_no, 'issueDate', up_1.passport_issue_date, 'issuerName', up_1.passport_issuer_name, 'issuerCode', up_1.passport_issuer_code) AS passport
           FROM profile.user_profile up_1
        ), addrt AS (
         SELECT r_address_type.id,
            r_address_type.code,
            r_address_type.name
           FROM profile.r_address_type
        ), cat AS (
         SELECT enum_contact_attribute_type_view.contact_attribute_type_code AS code,
            enum_contact_attribute_type_view.contact_attribute_type_name AS name
           FROM profile.enum_contact_attribute_type_view
        ), r AS (
         SELECT r_organization_role.id,
            r_organization_role.code,
            r_organization_role.name
           FROM profile.r_organization_role
        ), lsv AS (
         SELECT enum_legal_status_view.legal_status_code AS code,
            enum_legal_status_view.legal_status_name AS name
           FROM profile.enum_legal_status_view
        ), corp_form AS (
         SELECT r_corporate_form.id,
            r_corporate_form.code,
            r_corporate_form.short_name,
            r_corporate_form.full_name
           FROM profile.r_corporate_form
        ), dct AS (
         SELECT r_delivery_channel.id,
            r_delivery_channel.code,
            r_delivery_channel.name
           FROM profile.r_delivery_channel
        ), serv AS (
         SELECT r_service.id,
            r_service.code,
            r_service.name,
            r_service.description
           FROM profile.r_service
        )
 SELECT ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT up.first_name AS "firstName",
                    up.middle_name AS "middleName",
                    up.last_name AS "lastName",
                    up.birth_date AS "birthDate",
                    g.gender,
                    p.email AS "mainEmail",
                    ue.email_verified AS "emailVerified",
                    pass.passport,
                    up.snils,
                    up.inn
                   FROM (((profile.profile p
                     JOIN g ON (((up.gender)::text = (g.code)::text)))
                     JOIN pass ON ((pass.id = up.id)))
                     JOIN public.user_entity ue ON (((up.user_id)::text = (ue.id)::text)))
                  WHERE (p.id = up.id)) b) AS profile,
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT adr.id,
                    ( SELECT row_to_json(t.*) AS row_to_json
                           FROM ( SELECT addrt.code,
                                    addrt.name
                                   FROM addrt
                                  WHERE (addrt.id = adr.address_type)) t) AS type,
                    adr.address,
                    adr.account_no AS "accountNo"
                   FROM profile.address adr
                  WHERE (adr.profile_id = up.id)) b) AS address,
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT row_to_json(cat.*) AS type,
                    c.address,
                    c.confirmed
                   FROM (profile.contact_attribute c
                     JOIN cat ON (((c.type)::text = (cat.code)::text)))
                  WHERE (c.profile_id = up.id)
                  GROUP BY cat.*, c.address, c.confirmed) b) AS contacts,
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT org.id,
                    ( SELECT row_to_json(t.*) AS row_to_json
                           FROM ( SELECT r.code,
                                    r.name
                                   FROM r
                                  WHERE (r.id = mtm.role_id)) t) AS role,
                    org.short_name AS "shortName",
                    org.full_name AS "fullName",
                    ( SELECT row_to_json(lsv.*) AS row_to_json
                           FROM lsv
                          WHERE ((lsv.code)::text = (org.legal_status)::text)) AS "legalStatus",
                    ( SELECT row_to_json(t.*) AS row_to_json
                           FROM ( SELECT corp_form.code,
                                    corp_form.short_name AS "shortName",
                                    corp_form.full_name AS "fullName"
                                   FROM corp_form
                                  WHERE (corp_form.id = org.corporate_form_id)) t) AS "corporateForm",
                    org.registration_date AS "registrationDate",
                    date(to_timestamp((((org.created_at)::bigint / 1000))::double precision)) AS "systemRegistrationDate",
                    org.ogrn,
                    org.inn,
                    org.kpp,
                    org.head_person AS "headPerson",
                    org.representative_person AS "representativePerson",
                    org.main_okved AS "mainOkved",
                    org.additional_okved AS "additionalOkved",
                    org.website,
                    org.verified,
                    ( SELECT jsonb_agg(b_1.*) AS jsonb_agg
                           FROM ( SELECT ( SELECT row_to_json(t.*) AS row_to_json
   FROM ( SELECT addrt.code,
      addrt.name
     FROM addrt
    WHERE (addrt.id = a.address_type)) t) AS type,
                                    a.address
                                   FROM profile.address a
                                  WHERE (a.profile_id = org.id)) b_1) AS address,
                    ( SELECT jsonb_agg(b_1.*) AS jsonb_agg
                           FROM ( SELECT ( SELECT row_to_json(t.*) AS row_to_json
   FROM ( SELECT cat.code,
      cat.name
     FROM cat
    WHERE (c.id = c.id)) t) AS type,
                                    c.address,
                                    c.confirmed
                                   FROM profile.contact_attribute c
                                  WHERE (c.profile_id = org.id)) b_1) AS contacts
                   FROM (profile.mtm_organization_emp mtm
                     JOIN profile.organization_profile org ON ((mtm.organization_id = org.id)))
                  WHERE (mtm.user_profile_id = up.id)) b) AS organizations,
    ( SELECT json_agg(b.*) AS json_agg
           FROM ( SELECT ( SELECT json_agg(t.*) AS json_agg
                           FROM ( SELECT nt.code,
                                    nt.name,
                                    nt.description,
                                    ( SELECT row_to_json(t_1.*) AS row_to_json
   FROM ( SELECT serv.code,
      serv.name,
      serv.description
     FROM serv
    WHERE (serv.id = nt.service_id)) t_1) AS service,
                                    ( SELECT json_agg(( SELECT row_to_json(t_1.*) AS row_to_json
     FROM ( SELECT dct.code,
        dct.name
       FROM dct
      WHERE (dct.id = mtm.delivery_channel_id)) t_1)) AS json_agg) AS "deliveryChannel"
                                   FROM (profile.mtm_subscription mtm
                                     JOIN profile.r_notification_type nt ON ((nt.id = mtm.notification_type_id)))
                                  WHERE (mtm.profile_id = up.id)
                                  GROUP BY nt.code, nt.name, nt.description, nt.service_id) t) AS notification) b) AS subscriptions
   FROM profile.user_profile up
  GROUP BY up.id;


SET search_path = profile, pg_catalog;

--
-- Name: contact_attribute contact_attribute_ai_tr; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER contact_attribute_ai_tr AFTER INSERT ON profile.contact_attribute FOR EACH ROW EXECUTE PROCEDURE tr_contact_attribute_ai();


--
-- Name: contact_attribute contact_attribute_bd_tr; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER contact_attribute_bd_tr BEFORE DELETE ON profile.contact_attribute FOR EACH ROW EXECUTE PROCEDURE tr_contact_attribute_bd();


--
-- Name: mtm_organization_emp mtm_organization_emp2user_att_tr; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER mtm_organization_emp2user_att_tr AFTER INSERT OR DELETE OR UPDATE ON profile.mtm_organization_emp FOR EACH ROW EXECUTE PROCEDURE public.tr_mtm_organization_emp2user_att();


--
-- Name: organization_profile org_profile2user_att_tr; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER org_profile2user_att_tr AFTER INSERT OR UPDATE ON profile.organization_profile FOR EACH ROW EXECUTE PROCEDURE public.tr_org_profile2user_att();


--
-- Name: profile profile_ai_tr; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER profile_ai_tr AFTER INSERT ON profile.profile FOR EACH ROW EXECUTE PROCEDURE tr_profile_ai();


--
-- Name: user_profile tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.user_profile FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: contact_attribute tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.contact_attribute FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: organization_profile tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.organization_profile FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: mtm_subscription tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.mtm_subscription FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: mtm_organization_emp tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.mtm_organization_emp FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: notification tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.notification FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: mtm_contact_delivery_channel tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.mtm_contact_delivery_channel FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: address tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.address FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


--
-- Name: profile tr_log_table; Type: TRIGGER; Schema: profile; Owner: postgres
--

CREATE TRIGGER tr_log_table BEFORE INSERT OR DELETE OR UPDATE ON profile.profile FOR EACH ROW EXECUTE PROCEDURE logs.tf_log_table();


SET search_path = public, pg_catalog;

--
-- Name: user_attribute user_attribute_tr; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER user_attribute_tr BEFORE INSERT ON public.user_attribute FOR EACH ROW EXECUTE PROCEDURE attribute_value_trg();


--
-- Name: user_entity user_entity_ins_tr; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER user_entity_ins_tr AFTER INSERT OR UPDATE ON public.user_entity FOR EACH ROW EXECUTE PROCEDURE tr_user_entity_ins();


SET search_path = profile, pg_catalog;

--
-- Name: address fk_address_profile_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY address
    ADD CONSTRAINT fk_address_profile_id FOREIGN KEY (profile_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: address fk_address_type_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY address
    ADD CONSTRAINT fk_address_type_id FOREIGN KEY (address_type) REFERENCES r_address_type(id) MATCH FULL;


--
-- Name: contact_attribute fk_contact_attribute_tbl_profile_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY contact_attribute
    ADD CONSTRAINT fk_contact_attribute_tbl_profile_id FOREIGN KEY (profile_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: fact_indicator_actual fk_fact_indicator_category; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY fact_indicator_actual
    ADD CONSTRAINT fk_fact_indicator_category FOREIGN KEY (indicator_category_id) REFERENCES indicator_category(id) MATCH FULL;


--
-- Name: fact_indicator_actual fk_fact_indicator_profile; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY fact_indicator_actual
    ADD CONSTRAINT fk_fact_indicator_profile FOREIGN KEY (user_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: indicator_category fk_indicator_type_service_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY indicator_category
    ADD CONSTRAINT fk_indicator_type_service_id FOREIGN KEY (service_id) REFERENCES r_service(id) MATCH FULL;


--
-- Name: mtm_contact_delivery_channel fk_mtm_contact_delivery_channel_tbl_contact_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_contact_delivery_channel
    ADD CONSTRAINT fk_mtm_contact_delivery_channel_tbl_contact_id FOREIGN KEY (contact_id) REFERENCES contact_attribute(id) MATCH FULL ON DELETE CASCADE;


--
-- Name: mtm_contact_delivery_channel fk_mtm_contact_delivery_channel_tbl_delivery_channel_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_contact_delivery_channel
    ADD CONSTRAINT fk_mtm_contact_delivery_channel_tbl_delivery_channel_id FOREIGN KEY (delivery_channel_id) REFERENCES r_delivery_channel(id) MATCH FULL;


--
-- Name: mtm_notification_profile fk_mtm_notification_profile_tbl_notification_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_profile
    ADD CONSTRAINT fk_mtm_notification_profile_tbl_notification_id FOREIGN KEY (notification_id) REFERENCES notification(id) MATCH FULL;


--
-- Name: mtm_notification_profile fk_mtm_notification_profile_tbl_profile_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_profile
    ADD CONSTRAINT fk_mtm_notification_profile_tbl_profile_id FOREIGN KEY (profile_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: mtm_organization_emp fk_mtm_organization_emp_tbl_organization_profile; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_organization_emp
    ADD CONSTRAINT fk_mtm_organization_emp_tbl_organization_profile FOREIGN KEY (organization_id) REFERENCES organization_profile(id) MATCH FULL;


--
-- Name: mtm_organization_emp fk_mtm_organization_emp_tbl_r_organization_role; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_organization_emp
    ADD CONSTRAINT fk_mtm_organization_emp_tbl_r_organization_role FOREIGN KEY (role_id) REFERENCES r_organization_role(id) MATCH FULL;


--
-- Name: mtm_organization_emp fk_mtm_organization_emp_tbl_user_profile; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_organization_emp
    ADD CONSTRAINT fk_mtm_organization_emp_tbl_user_profile FOREIGN KEY (user_profile_id) REFERENCES user_profile(id) MATCH FULL;


--
-- Name: mtm_notification_delivery_task fk_notification_delivery_task_tbl_delivery_channel_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_delivery_task
    ADD CONSTRAINT fk_notification_delivery_task_tbl_delivery_channel_id FOREIGN KEY (delivery_channel_id) REFERENCES r_delivery_channel(id) MATCH FULL;


--
-- Name: mtm_notification_delivery_task fk_notification_delivery_task_tbl_notification_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_delivery_task
    ADD CONSTRAINT fk_notification_delivery_task_tbl_notification_id FOREIGN KEY (notification_id) REFERENCES notification(id) MATCH FULL;


--
-- Name: mtm_notification_delivery_task fk_notification_delivery_task_tbl_profile_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_notification_delivery_task
    ADD CONSTRAINT fk_notification_delivery_task_tbl_profile_id FOREIGN KEY (profile_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: r_notification_type fk_notification_service_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY r_notification_type
    ADD CONSTRAINT fk_notification_service_id FOREIGN KEY (service_id) REFERENCES r_service(id) MATCH FULL;


--
-- Name: notification fk_notification_tbl_organization_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT fk_notification_tbl_organization_id FOREIGN KEY (organization_id) REFERENCES organization_profile(id) MATCH FULL;


--
-- Name: notification fk_notification_tbl_sender_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT fk_notification_tbl_sender_id FOREIGN KEY (sender_id) REFERENCES user_profile(id) MATCH FULL;


--
-- Name: notification fk_notification_type_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY notification
    ADD CONSTRAINT fk_notification_type_id FOREIGN KEY (notification_type_id) REFERENCES r_notification_type(id) MATCH FULL;


--
-- Name: organization_profile fk_organization_profile_tbl_corporate_form; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY organization_profile
    ADD CONSTRAINT fk_organization_profile_tbl_corporate_form FOREIGN KEY (corporate_form_id) REFERENCES r_corporate_form(id) MATCH FULL;


--
-- Name: organization_profile fk_organization_profile_tbl_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY organization_profile
    ADD CONSTRAINT fk_organization_profile_tbl_id FOREIGN KEY (id) REFERENCES profile(id) MATCH FULL;


--
-- Name: mtm_subscription fk_subscription_delivery_channel_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_subscription
    ADD CONSTRAINT fk_subscription_delivery_channel_id FOREIGN KEY (delivery_channel_id) REFERENCES r_delivery_channel(id) MATCH FULL;


--
-- Name: mtm_subscription fk_subscription_notification_type; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_subscription
    ADD CONSTRAINT fk_subscription_notification_type FOREIGN KEY (notification_type_id) REFERENCES r_notification_type(id) MATCH FULL;


--
-- Name: mtm_subscription fk_subscription_profile_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY mtm_subscription
    ADD CONSTRAINT fk_subscription_profile_id FOREIGN KEY (profile_id) REFERENCES profile(id) MATCH FULL;


--
-- Name: user_profile fk_user_profile_tbl_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY user_profile
    ADD CONSTRAINT fk_user_profile_tbl_id FOREIGN KEY (id) REFERENCES profile(id);


--
-- Name: user_profile fk_user_profile_tbl_user_id; Type: FK CONSTRAINT; Schema: profile; Owner: postgres
--

ALTER TABLE ONLY user_profile
    ADD CONSTRAINT fk_user_profile_tbl_user_id FOREIGN KEY (user_id) REFERENCES public.user_entity(id) MATCH FULL ON UPDATE SET NULL;

SET search_path = webhook, pg_catalog;

--
-- Name: mtm_subscriber fk_mtm_subscriber_tbl_observable_entity_id; Type: FK CONSTRAINT; Schema: webhook; Owner: postgres
--

ALTER TABLE ONLY mtm_subscriber
    ADD CONSTRAINT fk_mtm_subscriber_tbl_observable_entity_id FOREIGN KEY (observable_entity_id) REFERENCES r_observable_entity(id) MATCH FULL;


--
-- Name: mtm_subscriber fk_mtm_subscriber_tbl_service_id; Type: FK CONSTRAINT; Schema: webhook; Owner: postgres
--

ALTER TABLE ONLY mtm_subscriber
    ADD CONSTRAINT fk_mtm_subscriber_tbl_service_id FOREIGN KEY (service_id) REFERENCES profile.r_service(id) MATCH FULL;


--
-- Name: api; Type: ACL; Schema: -; Owner: postgres
--

GRANT USAGE ON SCHEMA api TO api_anon;


SET search_path = api, pg_catalog;

--
-- Name: full-profile; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE "full-profile" TO api_anon;


--
-- Name: profile; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE profile TO api_anon;


--
-- Name: profile-addresses; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE "profile-addresses" TO api_anon;


--
-- Name: profile-contacts; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE "profile-contacts" TO api_anon;


--
-- Name: profile-organizations; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE "profile-organizations" TO api_anon;


--
-- Name: profile-subscriptions; Type: ACL; Schema: api; Owner: postgres
--

GRANT SELECT ON TABLE "profile-subscriptions" TO api_anon;


--
-- PostgreSQL database dump complete
--

